@@ -18,6 +18,7 @@ Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
 
 module DarcsURL (
     is_file, is_url, is_ssh, is_relative,
+    is_ssh_nopath
   ) where
 
 import Maybe ( isNothing, isJust )
@@ -51,11 +52,14 @@ match_not_file :: Regex
 match_not_file = mkRegex "..+:.+"
 match_url :: Regex
 match_url = mkRegex ".+://.+"
+match_ssh_nopath :: Regex
+match_ssh_nopath = mkRegex "^[^:]{2,}:$"
 
 is_relative :: String -> Bool
 is_file :: String -> Bool
 is_url :: String -> Bool
 is_ssh :: String -> Bool
+is_ssh_nopath :: String -> Bool
 
 is_relative (_:':':_) = False
 is_relative f@(c:_) = is_file f && c /= '/' && c /= '~'
@@ -64,3 +68,4 @@ is_relative "" = bug "Empty filename in is_relative"
 is_file fou = isNothing $ matchRegex match_not_file fou
 is_url s = isJust $ matchRegex match_url s
 is_ssh s = not (is_file s || is_url s)
+is_ssh_nopath s = isJust $ matchRegex match_ssh_nopath s
