@@ -267,7 +267,6 @@ copySSHs u ns d = do p <- try $ getEnv "SSH_PORT" -- or DARCS_SSH_PORT ?
                             hClose th
                             r <- exec sftp (sftp_args++["-b",tn,host])
                                  "/dev/null" sftpoutput
-                            output <- readFile sftpoutput
                             let files = if length ns > 5
                                           then (take 5 ns) ++ ["and "
                                                ++ (show (length ns - 5)) ++ " more"]
@@ -275,12 +274,14 @@ copySSHs u ns d = do p <- try $ getEnv "SSH_PORT" -- or DARCS_SSH_PORT ?
                                 hint = if take 1 path == "~"
                                          then ["sftp doesn't expand ~, use path/ instead of ~/path/"]
                                          else []
-                            when (r /= ExitSuccess) $
+                            when (r /= ExitSuccess) $ do
+                                 outputPS <- readFilePS sftpoutput
                                  fail $ unlines $
                                           ["(sftp) failed to fetch files.",
                                            "source directory: " ++ path,
                                            "source files:"] ++ files ++
-                                          ["sftp output:",output] ++ hint
+                                          ["sftp output:",unpackPS outputPS] ++
+                                          hint
 
 
 copyRemoteCmd :: String -> FilePath -> IO ()
@@ -562,8 +563,12 @@ verifyGPG goodkeys s =
       case rval of
           ExitSuccess -> return $ Just gpg_fixed_s
           _ -> return Nothing
-      where gpg_fixed_s = unlinesPS $ map fix_line $ tail $
-                          dropWhile (/= packString "-----BEGIN PGP SIGNED MESSAGE-----") $ linesPS s
+      where gpg_fixed_s = let
+                not_begin_signature x =
+                    x /= packString "-----BEGIN PGP SIGNED MESSAGE-----"
+                    && 
+                    x /= packString "-----BEGIN PGP SIGNED MESSAGE-----\r"
+                in unlinesPS $ map fix_line $ tail $ dropWhile not_begin_signature $ linesPS s
             fix_line x | lengthPS x < 3 = x
                        | takePS 3 x == packString "- -" = dropPS 2 x
                        | otherwise = x
