@@ -13,7 +13,7 @@
 int stdout_is_a_pipe() {
     struct stat s;
     int ret;
-    ret = fstat(1, &s);
+    ret = fstat(STDOUT_FILENO, &s);
     if (ret == 0)
         return !S_ISFIFO(s.st_mode);
     else
@@ -25,7 +25,7 @@ int stdout_is_a_pipe() {
 #include <io.h>
 #endif
 
-static int sloppy_atomic_create(const char *p)
+int sloppy_atomic_create(const char *p)
 {
     int fd;
     fd = open(p, O_WRONLY | O_EXCL | O_CREAT, 0666);
@@ -44,22 +44,6 @@ int atomic_create(const char *p)
 
 #else
 
-/* memrchr is a GNU extension, and rindex is BSD.  Roll our own. */
-
-static void *
-my_memrchr(const void *s, int c, int n)
-{
-    const char *ss = (const char *)s;
-    int i = n - 1;
-
-    while(i >= 0) {
-        if(ss[i] == c)
-            return (void*)(ss + i);
-        i--;
-    }
-    return NULL;
-}
-
 static int careful_atomic_create(const char *p)
 {
     /* O_EXCL is not available over NFSv2, and even under NFSv3, it is
@@ -92,11 +76,8 @@ static int careful_atomic_create(const char *p)
         hostname[15] = '\0';
     }
 
-    lastslash = my_memrchr(p, '/', strlen(p));
-    if(lastslash == NULL)
-        dirlen = 0;
-    else
-        dirlen = lastslash - p + 1;
+    lastslash = strrchr(p, '/');
+    dirlen = lastslash ? lastslash - p + 1 : 0;
 
     filename = malloc(dirlen + FILENAME_SIZE);
     if(filename == NULL)
@@ -187,29 +168,30 @@ int atomic_create(const char *p)
 #endif
 
 #ifdef _WIN32
-static int inited_rand = 0;
 int mkstemp(char *p)
 {
-    char* p2;
-    int fd;
-    int len = strlen(p);
-    if (len < 6)
+    static int inited_rand = 0;
+    size_t len = strlen(p);
+    if (len < 6 || strcmp(p+len-6, "XXXXXX")) {
+        errno = EINVAL;
         return -1;
-    if (!inited_rand) {
-      srand(time(0));
-      inited_rand = 1;
     }
-    snprintf(p+len-6, 6, "%06d", rand()+rand()<<16);
-    fd = open(p, O_CREAT | O_EXCL | O_RDWR, 0666);
-    return fd;
+    if (!inited_rand) {
+        srand(time(NULL));
+        inited_rand = 1;
+    }
+    // WARNING! The following is written for the win32 version of snprintf,
+    // which differs from the POSIX snprintf in how it treats the second
+    // argument.  The win32 snprintf doesn't print a nul character on
+    // overflow, so the second argument had better be one less than the
+    // size of the buffer, and the last character of the buffer had better
+    // be preset to nul.
+    snprintf(p+len-6, 6, "%06x", rand()<<16 ^ rand());
+    return open(p, O_CREAT | O_EXCL | O_RDWR, 0666);
 }
 
-int pipe( int fildes[2] ) {
-return _pipe( fildes, 8 * (2<<10), O_BINARY );
-}
-
-int isnt_symlink(const char *file) {
-  return 1; /* FIXME: should ignore windows shortcuts */
+int is_symlink(const char *file) {
+    return 0; /* FIXME: should ignore windows shortcuts */
 }
 
 static DWORD get_mode()
@@ -308,10 +290,10 @@ int execvp_no_vtalarm(const char *file, char *const argv[]) {
 #include <sys/types.h>
 #include <sys/stat.h>
 
-int isnt_symlink(const char *file) {
+int is_symlink(const char *file) {
   struct stat buf;
-  if (lstat(file, &buf)) return 0; /* treat error as symlink */
-  return !S_ISLNK(buf.st_mode);
+  if (lstat(file, &buf)) return 0; /* treat error as non-symlink */
+  return S_ISLNK(buf.st_mode);
 }
 
 #endif
