@@ -1,19 +1,20 @@
 #!/bin/sh
 set -ev
 
-DARCS=$PWD/../darcs
+test $DARCS || DARCS=$PWD/../darcs
 
 rm -rf temp1 temp2
 mkdir temp1 temp2
 cd temp1
-$DARCS inittree
+$DARCS init
 touch foo
 $DARCS add foo
 $DARCS record -a -m add_foo -A x
 $DARCS remove foo
 $DARCS record -a -m del_foo -A x
 cd ../temp2
-$DARCS inittree
+$DARCS init
 $DARCS pull --all ../temp1
 cd ..
 rm -rf temp1 temp2
+
