@@ -21,5 +21,5 @@ $DARCS mv afile.txt d/e/afile.txt
 echo altered_text > d/e/afile.txt
 $DARCS record --author me --all --no-test --patch-name confusion
 test ! -f _darcs/current/afile.txt
-echo yes | $DARCS unrecord
+echo y/d/y | tr / \\012 | $DARCS unrecord
 
