@@ -111,7 +111,11 @@ sub echo_to_darcs {
 
     my $superfluous = <$fh>;
     unlink $filename;
-    die "darcs did not read all input\n" if $superfluous;
+    if ($superfluous) {
+	use Test::Builder;
+	my $Test = Test::Builder->new;
+	$Test->ok (0, "superfluous input for $command");
+    }
 
     return $output;
 }
