@@ -10,7 +10,7 @@ use Shell::Command;
 use strict;
 use Carp;
 
-rm_rf 'temp1';
+cleanup 'temp1';
 mkdir 'temp1';
 chdir 'temp1';
 darcs 'init';
@@ -51,7 +51,7 @@ TODO: {
 ###
 
 chdir '../../../';
-rm_rf 'temp1';
+cleanup 'temp1';
 ok((!-d 'temp1'), 'temp1 directory was deleted');
 
 
