@@ -12,7 +12,7 @@ use vars qw/$DARCS/;
 die 'darcs not found' unless $ENV{DARCS} || (-x "$ENV{PWD}/../darcs");
 $DARCS = $ENV{DARCS} || "$ENV{PWD}/../darcs";
 
-rm_rf  'temp1';
+cleanup  'temp1';
 mkpath 'temp1';
 chdir 'temp1';
 darcs 'init';
@@ -40,7 +40,7 @@ like($record_output, qr/pending has conflicts/, 'darcs record reports "pending h
 like( darcs('repair'), qr/The repo is already consistent, no changes made/i, 'darcs repair finds no problem');
 
 chdir '../';
-rm_rf 'temp1';
+cleanup 'temp1';
 ok((!-d 'temp1'), 'temp1 directory was deleted');
 
 
