@@ -9,7 +9,7 @@ use Test::Darcs;
 use Shell::Command;
 use strict;
 
-rm_rf  'temp1';
+cleanup  'temp1';
 mkpath 'temp1';
 chdir  'temp1';
 darcs 'init';
@@ -60,5 +60,5 @@ TODO: {
 ####
 
 chdir '../';
-rm_rf 'temp1';
+cleanup 'temp1';
 ok((!-d 'temp1'), 'temp1 directory was deleted');
